@@ -1,4 +1,4 @@
-/* v0.8
+/* v0.9
  *
  * nav.h:  Navigation module header.
  *
@@ -18,4 +18,15 @@ extern void navUndock(TAG *, dbref, dbref);
 extern int navWarpCost(TAG *, float);
 extern void navOrbit(TAG *, dbref, int);
 extern float navMaxWarp(TAG *, int);
+extern void navRangeString(TAG *, range_t, char *, unsigned int);
+
+#ifdef ENABLE_ODOMETER
+extern void navSetOdometer(TAG *, int);
+extern void navWriteOdometer(dbref, SHIP *);
+#endif
+
+#ifdef ENABLE_TIME_TRACKER
+extern void navSetTimeActive(TAG *, time_t);
+extern void navWriteTimeActive(dbref, SHIP *);
+#endif
 
