@@ -1,4 +1,4 @@
-/* v0.8
+/* v0.9
  *
  * sensors.h:  Sensor module header.
  *
@@ -13,21 +13,9 @@
 #define DSD_ROUTINE             2
 #define DSD_DETAILED            3
 
-typedef struct distance_entry DISTENT;
-
-struct distance_entry {
-
-	TAG *object;
-	int range;
-/*	int width; */
-	DISTENT *next;
-	DISTENT *prev;
-
-};
-
-#define HubRange(pos)   (int) sqrt((double) pos.x*pos.x + (double) pos.y*pos.y + (double) pos.z*pos.z)
-
-extern DISTENT *dist_table[]; 	/* Table containing all objects */
+#define HubRange(pos)   (range_t) sqrt((double) pos.x*pos.x + \
+				       (double) pos.y*pos.y + \
+				       (double) pos.z*pos.z)
 
 extern void snsBuildDistanceTables(int);
 extern void snsFreeDistanceTables(int);
@@ -40,3 +28,12 @@ extern void snsListContacts(char *, CONTACT *, int, int);
 extern void snsScan(TAG *, dbref, int);
 extern void snsDisplaySensorInfo(TAG *, CONTACT *, dbref, int);
 extern void snsDisplayContacts(TAG *, dbref, int, int);
+extern void snsDisplayShortContacts(TAG *, dbref, int, int);
+extern void snsContactInfoString(TAG *, CONTACT *, char *);
+extern void snsContactString(TAG *, CONTACT *, char *buff);
+extern void snsAddObject(TAG *, int);
+extern void snsDelObject(TAG *, int);
+extern void snsSanityCheck(int);
+#ifdef ENABLE_INSTANT_UPDATE
+extern void snsUpdateDistanceTable(TAG *tag);
+#endif
