@@ -1,4 +1,4 @@
-/* v0.8
+/* v0.9
  *
  * shields.h:  Shields module header.
  *
@@ -8,10 +8,13 @@
  */
 
 extern void shdAllocCheck(TAG *);
-extern void shdAllocate(TAG *, dbref, int, int, int, int);
+extern void shdAllocate(TAG *, dbref, int*);
 extern void shdMaintainShields(TAG *);
 extern void shdCloakOn(TAG *, dbref);
 extern void shdCloakOff(TAG *, dbref);
 extern void shdRaiseShield(TAG *, dbref, int);
 extern void shdLowerShield(TAG *, dbref, int);
-
+extern const char *shdFullName(const TAG *, int);
+extern const char *shdShortName(const TAG *, int);
+extern const char *shdCharName(const TAG *, int);
+extern const char *shdConfigName(const TAG *);
